==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/scesim-marshaller/tests/idempotency.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as fs from "fs";
import * as path from "path";
import { getMarshaller } from "@kie-tools/scesim-marshaller";

const files = [
  "../tests-data--manual/simple.scesim",
  "../tests-data--manual/OldEnoughTest.scesim",
  "../tests-data--manual/TrafficViolationTest.scesim",
];

describe("idempotency", () => {
  for (const file of files) {
    test(path.basename(file), () => {
      const xml_original = fs.readFileSync(path.join(__dirname, file), "utf-8");

      const { parser, builder } = getMarshaller(xml_original);
      const json = parser.parse();

      const xml_firstPass = builder.build(json);
      const xml_secondPass = builder.build(getMarshaller(xml_firstPass).parser.parse());

      expect(xml_firstPass).toStrictEqual(xml_secondPass);
    });
  }
});

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/scesim-marshaller/tests/idempotency.test.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as fs from "fs";
import * as path from "path";
import { getMarshaller } from "@kie-tools/scesim-marshaller";

const files = [
  "../tests-data--manual/dmn/collection.scesim",
  "../tests-data--manual/dmn/expression.scesim",
  "../tests-data--manual/dmn/imported.scesim",
  "../tests-data--manual/dmn/simple.scesim",
  "../tests-data--manual/dmn/simpleTypes.scesim",
  "../tests-data--manual/dmn/TrafficViolationTest.scesim",
  "../tests-data--manual/dmn/undefined.scesim",
  "../tests-data--manual/rule/OldEnoughTest.scesim",
];

describe("idempotency", () => {
  for (const file of files) {
    test(path.basename(file), () => {
      const xml_original = fs.readFileSync(path.join(__dirname, file), "utf-8");

      const { parser, builder } = getMarshaller(xml_original);
      const json = parser.parse();

      const xml_firstPass = builder.build(json);
      const xml_secondPass = builder.build(getMarshaller(xml_firstPass).parser.parse());

      expect(xml_firstPass).toStrictEqual(xml_secondPass);
    });
  }
});
